/* 
Mikroekonometria 
Zajęcia 7- Testowanie hipotez w MNW
CC BY: Wiktor Budziński
*/

use me_apples.dta, clear
gen eco = ecolbs > 0 // Tworzymy zmienną, która mówi nam czy ktoś w ogóle kupił eko-jabłka

// Zadanie 3. Eko-jabłka
// 3.1. Czy wszystkie parametry są łącznie  istotne?

logit eco educ regprc ecoprc inseason male faminc numlt5 num5_17 num18_64 numgt64

scalar LL_U = e(ll) // Zapisujemy wartość LL z modelu jako skalar
logit eco // Liczymy model tylko ze stałą
scalar LL_R = e(ll) // Zapisujemy wartość LL dla modelu ze stałą

scalar LR = -2*(LL_R - LL_U) //Liczymy wartość statystyki testowej LR
display LR // Możemy ją wypisać na ekran
display 1-chi2(10, LR) // Liczymy p-value, liczba stopni swobody równa się 10, bo tyle zmiennych mieliśmy w modelu

// Alternatywnie
quietly logit eco educ regprc ecoprc inseason male faminc numlt5 num5_17 num18_64 numgt64
estimates store unrestricted
quietly logit eco 
estimates store restricted
lrtest restricted unrestricted
						
// 3.1. Czy ceny zwykłych jabłek i eko-jabłek mają tę samą siłę oddziaływania (choć w przeciwną stronę)?

// Liczymy ponownie nasz model
logit eco educ regprc ecoprc inseason male faminc numlt5 num5_17 num18_64 numgt64

test regprc + ecoprc == 0 // H0: Restrykcje nie pogarszają dopasowania modelu do danych

scalar LL_U = e(ll) // Zapisujemy wartość LL z modelu bez restrykcji

// Czasem możemy chcieć oszacować model, w którym nakładamy jakieś restrykcje na oszacowania parametrów. Można to zrobić w następujący sposób:
// Najpierw definiujemy wszystkie ograniczenia jakie chcemy (w tym przypadku jedno)
constraint define 1 [eco]ecoprc + [eco]regprc = 0

// Następnie dodajemy po przecinku opcję restrykcji (w nawiasie wypisujemy numery restrykcji, które chcemy uwzględnić - w tym przypadku jedynie pierwszą restrykcję)
logit eco educ regprc ecoprc inseason male faminc numlt5 num5_17 num18_64 numgt64, constraint(1)
// Alternatywnie:
gen pricediff = regprc - ecoprc
logit eco educ pricediff inseason male faminc numlt5 num5_17 num18_64 numgt64

scalar LL_R = e(ll) // Zapisujemy wartość LL z restrykcją 
scalar LR = -2*(LL_R - LL_U) //Liczymy wartość statystyki testowej LR
display LR // Możemy ją wypisać na ekran
display 1-chi2(1, LR) // Liczymy p-value, liczba stopni swobody równa się 1, bo testujemy jedną restrykcje
// P-value > 0.05 => Nie ma podstaw do odrzucenia hipotezy zerowej

// 3.3. Czy cena eko-jabłek ma inny wpływ na mężczyzn niż na kobiety?

// Liczymy ponownie nasz model
logit eco educ regprc ecoprc inseason male faminc numlt5 num5_17 num18_64 numgt64

scalar LL_R = e(ll) // Zapisujemy wartość LL z podstawowego modelu jako modelu z restrykcjami

logit eco educ regprc ecoprc inseason male faminc numlt5 num5_17 num18_64 numgt64 i.male#c.ecoprc
// Statystyka Z wskazuje, że interakcja jest nieistotna

logit eco educ regprc inseason male faminc numlt5 num5_17 num18_64 numgt64 i.male#c.ecoprc 

logit eco educ regprc inseason faminc numlt5 num5_17 num18_64 numgt64 i.male##c.ecoprc 

scalar LL_U = e(ll) // Zapisujemy wartość LL z modelu z interakcją
scalar LR = -2*(LL_R - LL_U) //Liczymy wartość statystyki testowej LR
display LR // Możemy ją wypisać na ekran
display 1-chi2(1, LR) // Liczymy p-value, liczba stopni swobody równa się 1, bo testujemy jedną interakcję
// P-value > 0.05 => Nie ma podstaw do odrzucenia hipotezy zerowej

// 3.4 Porównaj model z liniowymi cenami z modelem z zlogarytmowanymi cenami
// Wykorzystaj test Vounga

// Model nr 1
logit eco educ regprc ecoprc inseason male faminc numlt5 num5_17 num18_64 numgt64
predict p, pr // przewidujemy p-stwo
gen LL_score1 = log(p*eco + (1-p)*(1-eco))

// Model nr 2
gen lregprc = log(regprc)
gen lecoprc = log(ecoprc)
logit eco educ lregprc lecoprc inseason male faminc numlt5 num5_17 num18_64 numgt64
predict p2, pr // przewidujemy p-stwo
gen LL_score2 = log(p2*eco + (1-p2)*(1-eco))

// Test Vounga
gen Diff = LL_score2 - LL_score1
sum Diff
scalar Voung = r(N)*r(mean)/(sqrt(r(N))*r(sd))
display Voung // Statystyka testowa
display 2*(1-normal(abs(Voung))) // P-value
// Alternatywnie: Sprawdzic czy statystyka testowa jest miedzy -1.96 a 1.96
display 2*(1-normal(abs(-1.96)))

// 3.5 Porównaj model z liniowymi cenami z modelem z ilorazem cen

// Test Vounga dla modeli z rozna liczba parametrów
gen PriceRatio = regprc/ecoprc
logit eco educ PriceRatio inseason male faminc numlt5 num5_17 num18_64 numgt64
predict prob3, pr // przewidujemy p-stwo
gen LL_score3 = log(prob3*eco + (1-prob3)*(1-eco))
gen Diff2 = LL_score1 - LL_score3
sum Diff2
// Bez brania pod uwagę liczby parametrów
scalar Voung2a = r(N)*r(mean)/(sqrt(r(N))*r(sd))
display Voung2a // Statystyka testowa
// Biorac to pod uwage
scalar Voung2b = (r(N)*r(mean) - 1*log(r(N))/2)/(sqrt(r(N))*r(sd))
display Voung2b // Statystyka testowa